User Guide
==========

How Ironic Inspector Works
--------------------------

.. toctree::
  :maxdepth: 2

  workflow

How to use Ironic Inspector
---------------------------

.. toctree::
  :maxdepth: 2

  usage

HTTP API Reference
------------------

* `Bare Metal Introspection API Reference
  <https://docs.openstack.org/api-ref/baremetal-introspection/>`_.

Troubleshooting
---------------

.. toctree::
  :maxdepth: 2

  troubleshooting


.. toctree::
  :hidden:

  http-api
